import { Injectable } from '@angular/core'

import { Observable, of as observableOf } from 'rxjs'
import { map } from 'rxjs/operators'

// import { Apollo, gql } from 'apollo-angular'

import { AdminService, AdminBasket, BasketNameOnly, Project,
    BasketImportResult
 } from '../../openapi'

export class AdminBasketFile {
    constructor(
        public id: number,
        public dir: string,
        public name: string,
        public url: string,
        public md5: string,
        public time: Date,
        public comment: string,
        public status: string,
        public store: string,
        public project: string,
        public surveyor: string,
        public equipment: string,
        public import_result?: string,
    ) {}
}

export class AdminBasketUploadFieldData {
    constructor(
        public stores: string[],
        public statuses: string[],
        public projects: string[],
        public surveyors: string[],
        public equipments: string[],
    ) {}
}

@Injectable()
export class AdminBasketDataService {
    constructor(
        // private apollo: Apollo,
        public adminService: AdminService,
    ) {}

    getBaskets(): Observable<BasketNameOnly[]> {
        // Get the list a basket names
        return this.adminService.getBasketsApiAdminBasketGet()
    }

    getBasketUploadFieldData(): Observable<AdminBasketUploadFieldData> {
        // Get the list a basket names
        console.warn('Migrate Graphql')
        return observableOf()
        // return this.apollo.query({
        //     query: getAdminBasketUploadFieldDataQuery,
        // }).pipe(map(
        //     res => res['data']['admin_basket_upload_field_data'].map(
        //         (data: object) => new AdminBasketUploadFieldData(
        //             data['store'],
        //             data['status'],
        //             data['project'],
        //             data['surveyor'],
        //             data['equipment'],
        //         )
        //     )
        // ))
    }

    getBasket(name: string): Observable<AdminBasket> {
        // Get all info and content of a basket
        return this.adminService.getBasketApiAdminBasketNameGet({name: name})
    }

    importItem(basket: string, fileId: number, dryRun: boolean=false): Observable<BasketImportResult> {
        return this.adminService.importBasketFileApiAdminBasketImportBasketFileIdGet({
            basket: basket,
            fileId: fileId,
            dryRun: dryRun
        })
        console.warn('Migrate Graphql')
        return observableOf()
        // return this.apollo.mutate({
        //     mutation: importAdminBasketItemMutation,
        //     variables: {
        //         basket: basket,
        //         id: id,
        //         dryRun: dryRun
        //     }
        // }).pipe(map(
        //     resp => new BasketImportResult(
        //         resp['data']['importBasketItem']['result']['time'],
        //         resp['data']['importBasketItem']['result']['message'],
        //         JSON.parse(resp['data']['importBasketItem']['result']['details']),
        //     )
        // ))
    }

    deleteItem(basket: string, id: number) {
        console.warn('Migrate Graphql')
        return observableOf()
        // return this.apollo.mutate({
        //     mutation: deleteAdminBasketItemMutation,
        //     variables: {
        //         basket: basket,
        //         id: id,
        //     }
        // }).pipe(map(
        //     resp => resp['data']['deleteBasketItem']['result']
        // ))
    }
}